package com.muyu.config;

import com.muyu.utils.AesUtil;
import com.zaxxer.hikari.HikariDataSource;
import lombok.extern.log4j.Log4j2;
import org.springframework.boot.autoconfigure.jdbc.DataSourceProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.sql.Connection;

/**
 * @Author: DongZeLiang
 * @date: 2024/9/11
 * @Description: 数据源配置
 * @Version: 1.0
 */
@Log4j2
@Configuration
public class DataSourceConfig {

    /**
     * 初始化数据源Bean
     * @param dataSourceProperties 数据库配置
     * @return hikari数据源
     */
    @Bean
    public HikariDataSource initDataSource(DataSourceProperties dataSourceProperties) throws Exception {
        HikariDataSource hikariDataSource = new HikariDataSource();
        hikariDataSource.setJdbcUrl(dataSourceProperties.getUrl());
        hikariDataSource.setUsername(dataSourceProperties.getUsername());
        hikariDataSource.setPassword(AesUtil.decrypt(dataSourceProperties.getPassword()));
        hikariDataSource.setDriverClassName(dataSourceProperties.getDriverClassName());
        Connection connection = hikariDataSource.getConnection();
        log.info("数据源初始化成功");
        hikariDataSource.evictConnection(connection);
        return hikariDataSource;
    }
}
